Learn R Programming

phenModel (version 1.0)

pvulg_budburst_parameters: Estimated Parameters for the Exponential Decay Model for Budburst

Description

Vector of estimated parameters.

Usage

data("pvulg_budburst_parameters")

Arguments

Format

The format is: Named num [1:2] 540.196 -0.016 - attr(*, "names")= chr [1:2] "b" "m"

Details

The method implied is based on the Alternating Model, which is a degree-day model that accumulates thermal/chilling units above/below a base threshold from a specified date (Cannell and Smith, 1983). The b and m values correspond to the estimates for budburst for Salix viminalis (Pollard et al., submitted).

References

Cannell, M.G.R. and Smith, R.I. (1983) Thermal time, chill days and prediction of budburst in Picea sitchensis. Journal of Applied Ecology, 20(3), 951<U+2013>963.

Pollard C.P., Griffin C.T., Moral R.A., Duffy C., Chuche J., Gaffney M.T., Fealy R. (submitted) phenModel: a temperature-dependent phenology model for the blue willow beetle, Phratora vulgatissima.

Examples

Run this code
# NOT RUN {
data(pvulg_budburst_parameters)
# }

Run the code above in your browser using DataLab